Modules
Structs
- A parsed RTP packet. A wrapper around a byte slice. Each field is only accessed when needed
- Struct for building a new RTP packet
- Packet editing
- An implementation of a
RtpPacketWriterthat writes to a&mut [u8]. Each packet will be written starting at the beginning of the provided slice. - An implementation of a
RtpPacketWriterthat writes to a&mut Vec<u8>. Each packet written will be appended to the provideVec<u8>. You canclear()the vec in between packets to have each packet written from the beginning of the vec. - An implementation of a
RtpPacketWriterthat appends to aVec<u8>
Enums
- An error produced when parsing a packet
- Errors produced when wrting a packet