pub enum RtpParseError {
UnsupportedVersion(u8),
Truncated {
expected: usize,
actual: usize,
},
PaddingInvalid(u8),
}Expand description
An error produced when parsing a packet.
Variants
UnsupportedVersion(u8)
Version is unsupported. This implementation only supports version 2.
Truncated
There is not enough data available to successfully parse the packet
PaddingInvalid(u8)
The padding byte does not contain a valid value.