Struct rtp_types::RtpPacket

source ·
pub struct RtpPacket<'a> { /* private fields */ }
A parsed RTP packet. A wrapper around a byte slice. Each field is only accessed when needed

Implementations

source

impl<'a> RtpPacket<'a>

source

pub const MIN_RTP_PACKET_LEN: usize = 12usize

The minimum number of bytes a RTP packet must be to be parsed correctly

source

pub const MAX_N_CSRCS: usize = 15usize

The maximum number of CSRCs a RTP packet can contain

source

pub fn parse(data: &'a [u8]) -> Result<RtpPacket<'a>, RtpParseError>

Parse a byte slice into a RtpPacket. This implementation prefers to fail fast and will return errors when the size of passed in data is not sufficient for values described in the data.

source

pub fn version(&self) -> u8

The RTP version in this packet. Only version 2 is supported.

source

pub fn padding(&self) -> Option<u8>

Returns the number of bytes of padding used by this packet or None

source

pub fn n_csrcs(&self) -> u8

Returns the number of Contribution Sources for this packet. May not be used by this packet.

source

pub fn marker(&self) -> bool

Returns whether the marker bit is set for this packet. The meaning of the marker bit is payload-specific

source

pub fn payload_type(&self) -> u8

Returns the payload type for this packet.

source

pub fn sequence_number(&self) -> u16

Returns the sequence number for this packet

source

pub fn timestamp(&self) -> u32

Returns the RTP timestamp for this packet

source

pub fn ssrc(&self) -> u32

Returns the Sychronisation Source for this packet

source

pub fn csrc(&self) -> impl Iterator<Item = u32> + '_

Returns a (potentially empty) iterator over the Contribution Sources for this packet

source

pub fn extension(&self) -> Option<(u16, &[u8])>

Returns the extension data for this packet. The first value is an identifier and is ‘defined by the RTP profile’. The second value is the extension data.

source

pub fn payload(&self) -> &[u8]

Returns the payload data

source

pub fn as_builder(&'a self) -> RtpPacketBuilder<&'a [u8], &'a [u8]>

Creates a builder that will be able to reconstruct this packet byte for byte (excluding any padding bytes). Any aspect of the returned builder can be modified.